#
# spec file for package attractmode
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           attractmode
Version:        2.6.1
Release:        bp155.2.13
Summary:        A graphical frontend for emulators
License:        GPL-3.0-only
Group:          System/Emulators/Other
URL:            https://attractmode.org
Source0:        https://github.com/mickelson/attract/archive/v%{version}/attract-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  freeglut-devel
BuildRequires:  gcc-c++
BuildRequires:  libjpeg8-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(libarchive)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(xcb-xinerama)
Requires(post): desktop-file-utils
Requires(postun): desktop-file-utils
BuildRequires:  sfml2-devel

%description
Attract-Mode is a graphical frontend for command line emulators such as MAME,
MESS and Nestopia. It hides the underlying operating system and is intended to
be controlled with a joystick, gamepad or spinner, making it ideal for use
in arcade cabinets.

%prep
%setup -q -n attract-%{version}

%build
%make_build EXTRA_CFLAGS="%{optflags}" prefix=%{_prefix}

%install
%make_install prefix=%{_prefix}

# Install icon and appdata- and .desktop-file
install -Dm644 util/linux/attract-mode.appdata.xml %{buildroot}%{_datadir}/appdata/attract-mode.appdata.xml
install -Dm644 util/linux/attract-mode.png         %{buildroot}%{_datadir}/icons/hicolor/512x512/apps/attract-mode.png
install -Dm644 util/linux/attract-mode.desktop     %{buildroot}%{_datadir}/applications/attract-mode.desktop

# Hardlinks so users can copy it
%fdupes %{buildroot}%{_datadir}/attract

%post
%desktop_database_post

%postun
%desktop_database_postun

%files
%doc Readme.md
%license License.txt
%{_bindir}/attract
%{_datadir}/attract
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/512x512
%dir %{_datadir}/icons/hicolor/512x512/apps
%{_datadir}/icons/hicolor/512x512/apps/attract-mode.png
%{_datadir}/applications/attract-mode.desktop
%{_datadir}/appdata/attract-mode.appdata.xml

%changelog
* Fri Mar 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 2.6.1. Too many changes since the 2.5.0 release.
  Check https://github.com/mickelson/attract/releases.
- Spec cleanup.
* Sat Nov 10 2018 Luke Jones <jones_ld@protonmail.com>
- appdata-desktop.patch removed, fixed upstream.
- fix-no-return-in-nonvoid-function.patch removed, fixed upstream.
- fix-install-target.patch removed, fixed upstream.
- Update to version 2.5.0
  + Issue #481: Allow use of any of the 'magic tokens' in emulator arguments
  + Fix some compile warnings
  + Optimization for quicker artwork loading
  + [Windows] extra measures to stop losing foreground focus
  + [Windows] Issue #482 - Fix for unicode filenames in squirrel standard lib
  + Added "Please Wait" message
  + [Windows] Fix handling of unicode characters in filenames
  + Added fe.get_text() function for getting translated strings from a script
  + Switched to use libcurl for network scraping (#486)
  + Fixed pause on raspberry pi
  + Added Pause Emulator functionality (#479)
  + [linux] Always close frontend window when launching from fullscreen mode linux
  + Issue #334 - removed git dependency from Makefile
  + [Windows] make output from fe.plugin_command() consistent with Linux/OS X
  + Issues #379, #248 - Fix to allow user to escape hung artwork scraping
  + Added ChangedTag transition when a game is faved or tagged
  + Update expat xml parser to version 2.2.6 (#480)
  + Issue #472 - Added setting to control pointer moving on emu launch
  + Issue # 325 - tweaked selection acceleration, added the "selection_max_step" option to attract.cfg
  + Issue #471 - fix scraping of overview info (blank entries)
  + Display link typo resolved (#485)
  + Add 'Exit Message' option to General settings (#363)
  + Added Overlay.Favourite command to Transition.ShowOverlay (#484)
  + Added BlendMode.Subtract, fixed line endings in default shader files (#477)
  + Improve french translation (#495)
- Update to version 2.4.1
  + Added log message when frontend unexpectedly loses focus
  + Added code to handle mame/mess media types during first run autoconfiguration
  + Misc. code cleanup (removed unused variables, etc)
  + Issue #282 - fixed mapped keys from working when frontend doesn't have focus
  + Switch behaviour of "Fillscreen mode" to a true borderless window (#467)
  + Added bound check (+ correction) for video pts
  + Improved frame skipping for videos
  + Fix 'non-blocking mode wait' when game has multiple loading screens
  + Fix sound handling when interrupted by game launch
  + Updated setting of hwaccel in FFmpeg. Added videotoolbox for Mac OS X
  + Issue #459 - fixed listbox selection background fading/colour setting
  + RocketLauncher plugin (#470) - Written by ArcadeBliss
  + Added manifest to windows build (#461)
- Update to version 2.4.0
  + [windows] combine attract.exe and attract-console.exe into the same package
  + Issue #401 - Implement proposed changes to zorder behaviour (#408)
  + Reduce unnecessary redrawing on some layouts
  + Issue #391 - store overview information by emulator
  + Issue #456 - properly reset layout state when new layout configured
  + Added .travis.yml
  + Issue #455 - fix handling of menu artwork
  + Issue #454 - fixed thegamesdb.net scraping (url changed)
  + Issue #452, #446 - fix compile on old SFML version
  + Issue #444 - added "Layout Options" to go straight to layout configuration
  + Various changes to merge oomek-fixes branch, including fix_filters() bugfix
  + [linux] Issue #393 - fix handling of single quotes and related commandline parameter issues
  + Fix compile on older SFML versions after Text .spacing parameter changes
  + Fix whitespace and reordering
  + Issue #440 - attempt to prevent reported file lockup on missing artwork
  + [Windows] enabled d3d11 hwaccel decode option, if available
  + Issue #436 - allow user to select which layout.nut file to use from Layout config
  + Update Layouts.md for the blend_mode changes
  + Added config file parameter output to debug logging
  + Added support for "per display" layout parameters.
  + Minor fixes to android build, "edit game" option
  + [linux] default to "fullscreen mode" window mode
  + Don't use network scraping when doing automatic import at startup
  + removed stray debug message
  + Automatically import emulators that are detected on startup
  + Autodetect emulators and generate emulator templates on first run
  + Issue #400 - reduce CPU usage when idle
  + Issue #407 - fixed fe.Image.video_playing attribute
  + Added ability use emulator templates when adding a new emulator
  + [linux] enabled exit hotkeys when in fullscreen mode, added debug logging for window creation/destruction
  + Made wheel fadeout time configurable for hyperspin-based layouts
  + Added fe.path_test() command for layout/plugin scripts
  + Relabelled and reworked the 'minimum_wait_time' emulator setting
  + Changed scummvm info_source to only use 'scummvm -t' output
  + [linux] added VDPAU hwaccel support and fixes for VAAPI
  + Added android readme, minor updates to compile.md and gameswf compile
  + Fix compile on MacOS Sierra
  + [android] initial addition of experimental android support
  + Added support for touch events if provided by SFML (swipe, tap)
  + Added fe_file.cpp to load images, fonts, sounds through a file stream
  + Fix window focus detection when min_run_time is set
  + Issue #388 - fix compile on Ubuntu 14.04
  + Issue #385 - fix recent compile fix for older versions of avcodec
  + Fix compile with NO_MOVIE=1
  + Fix potential race condition in scraper
  + Issue #385 - fix compile error on Jessie
  + C++11 Syntax Fix
  + RPI: update for new vendor library names & add Mesa VC4 override
  + Update Dolphin config (#417)
  + Update Ubuntu version (#416)
  + [linux] Update version number and icon path (#414)
  + debian/install - Copy single files first (#415)
  + Updated Compile.md for a Command line error + Detail (#425)
  + Buttons scraped with newer mame.xml file
  + Improve Multi Monitor support (#405) and fix NES romlist crash
  + New text alignment modes (#448)
  + Added list_size property to fe.ListBox
  + Fixed Fill Screen window offset, update
  + Fixed Fill Screen window offset
  + Fixed back buffer blinking on game launch
  + Blend mode refactoring
  + Whitespace cleanup
  + Added a folder with default shaders for each blend mode
  + Blend modes improvements
  + Sorting fixes
  + Fixed borderless window size
  + added blend modes to fe.Image
  + Added .spacing parameter to fe.Text
  + Added .mipmap parameter to fe.Image
  + Fixed video restarting after setting video_playing = false (#411)
- Update to version 2.3.0
  + Added --loglevel and --logfile commandline options
  + [Windows] Switched Attract-Mode to a Windows GUI app
  + Issue #381 - fixed crash when using Shader.Empty
  + Joystick mapping must now be done manually from Config->Controls->Joystick Mappings
  + Fix handling of conflicting input mappings in configuration mode
  + [rpi] Removed assumption that rasberry pi always uses GLES
  + Initial addition of Direct X Video Acceleration (Windows) and VAAPI (Linux) support
  + Issue #372 - Added plugin to change display on joystick input
  + [Attrac-Man] Fixed ghost and player UI movement around the "Ghost House"
  + Update look of Attrac-Man layout
  + Updated config so that Joystick slots can be mapped to specific named devices
  + added "Insert Game" command
  + Added UI functionality to edit shortcuts
  + Only use CRC matching on rom 10 megs or less when scraping
  + Initial support for shortcut navigation and multiple level menus
  + Tweak to 7a7afa5 to fix last launch saving
  + Added some missing bound checks when loading state
  + [linux] Issue #343 - don't leave zombies when exit hotkey is used
  + Disable further FE navigation when launch game sound is playing
  + Issue #333 - don't replay launch sound if in the process of launching a game
  + Added nomargin Text attribute to layout documentation
  + Issue #329 - smarter redrawing of surfaces
  + Fixed multimonitor bug (Fix provided by Mike Balfour)
  + Update Attrac-Man layout to use artwork fades
  + Enable animated gifs
  + [windows] Fix "Fill Screen Mode" on Win10
  + [linux] Issue #318 - fix compile on Linux with older SFML versions
  + [linux] reduced delay when launching emulator in "Fullscreen Mode"
  + [windows] Issue #296 - fix for white screen flicker on game launch and exit
  + Fix extensions in default dolphin configuration
  + [windows] Added NvOptimusEnablement and AmdPowerXpressRequestHighPerformance exports
  + The "edit game" action will now edit the display settings when used on the displays menu
  + Removed unnecessary video frame queuing, simplifying code
  + Added support for CUVID and QSV hardware accelerated video decoding
  + Issue #304 - hyperspin overlayoffset fix (patch from joyrider3774)
  + Changed sleep timer for smoother animation
  + Added scraping of mame artwork from adb.arcadeitalia.net
  + Fixed "scrape mamedb.com" and "scrape overview" option loading/saving
  + Issue #297 - fix hidden displays causing wrong selection in "displays menu"
  + Use mamedb.blu-ferret.co.uk for mamedb scraping
  + Updated Italian translation (P. Ghezzo)
  + Added screensaver options to run commands when starting or stopping "blank screen" mode
  + Fixed key handling to return from screensaver. Fix build with NO_SWF=1 option
  + Added blank screen (low power mode) setting to default screensaver.
  + Added config option for confirmation prompt on exit
  + Save location in the playlist when launching a game
  + "Hide Console" option should only be for Windows (whoops)
  + Add $PROGDIR variable/expansion for substituting program directory in path leadings
  + Add 'Hide Console' option to General settings
  + Added more file types for Dolphin roms
  + Fix bug where wheel doesn't scroll down or right if you move the trackball slowly . (#322)
  + Extlibs: Fixed nonvoid function without return value in gameswf. (#321)
  + [linux] Added appdata file (#319)
  + Makefile: Fix install target for mac and some linux distros
  + Korean localisation
  + Fixed bluring of small fonts in X axis when textbox has a fractional width
  + Fixed 1 pixel offset
  + tp.cpp whitespace cleanup
  + fe.Textbox improvements
  + Try to correct positions for some themes with certain swf artwork
  + Fix zorder + implement zorder related below tag
* Thu Mar  2 2017 rpm@fthiessen.de
- Use bundled .desktop file
- Compile with correct prefix (needed for DATA_PATH in fe_settings)
  and with optflags
  * Added fix-no-return-in-nonvoid-function.patch to fix
  + nonvoid functions without return valuu.
- Workaround for missing appdata directory on Leap 42.1
- Reported appdata file upstream
  * appdata-desktop.patch
- Added to fix fix-install-target.patch install-target
  of the makefile.
* Thu Feb  9 2017 luke.nukem.jones@gmail.com
- Update to version 2.2.1
  + + [linux] fixes for multimonitor mode with X11
  + + [rpi] Misc. cleanup of emulation launching on the RPi
  + + Added a description of the default controls to the readme
  + + Fix move speed in config menus when key held down
  + + Fix freetype2 header not found during compile
  + + [linux] Added --console cmdline option to enable script from console
  + + Improved combo key handling, added more initial key mappings
  + + Default "Confirm Favourites" value is now "true"
  + + Fix audio volume changing for layout sounds after running emulator
  + + Add cn entry in en.msg
  + + [linux] Smoother transition to emulator from 'fullscreen mode'
  + + Added "Working Directory" emulation setting
  + + Minor reorder of options in the misc. config menu
  + + Issue #250 - Fix improper handling of "Upos" joystick axis
  + cn.msg
  + Create Linux desktop entry
  + Support for wheel fade
* Sun Nov 20 2016 luke.nukem.jones@gmail.com
- Issue #250 - Fix improper handling of "Upos" joystick axis
- Added scraping of game overview text from thegamesdb.net
- Added configure option to disable scraping of mamedb.com
- Fixed "Toggle Layout" when used on the displays menu layout
- Added layout options configuration for 'Displays Menu' layout
- [rpi] Issue #266 - Fix for keypresses being cached w/ sfml-pi build (non-X11)
- Added ability to set image origin in scripts (for centre rotations etc)
- Added customized layouts for the diplays menu/system selection menu
- Issue #264 - fixed SWF crash when unimplemented actionscript constant types encountered
- Added a no border window mode
- Issue #258 - Windows 10 v.1607 task bar fix (Fullscreen Mode)
- Limit the squirrel script functions available when gathering plugin descriptions
- Added an "RGB Movie" mode to the screensaver
- Updated the "Keyboard Search" plugin so "Back" clears the current search
- [linux] Fixed potential hang when waiting for emulator exit
- Issue #262 - Fixed sound volume setting after game return
- Added ability to generate multi-emulator romlists to the configuration interface.
- Misc. fixes to internationalization, updated italian translation
- Minor changes to mutex usage in media player
- Added ability to set a custom executable and arguments for each game
- Added an "Edit Game" action
- Fixed jumping cursor bug when using keyboard to edit
- Refactor of thegamesdb_scraper()
- Updates to the italian translation (P. Ghezzo)
- Fix cancel using the back button during scraping
- Added basic ability to edit text using a control pad (in config mode)
- [rpi] Default to "Fill Screen Mode" on the Raspberry Pi
- [linux] fix focus issues with exit hotkeys and "fullscreen mode"
- Issue #246 - Added ability to import mame listsoftware format xml
- Issue #247 - fixed the "Show in cycle" display setting
- Fixed memory leak when video frames are dropped
- Issue #245 - fixed fade module getting stuck when no image found
- [rpi] Issue #236 - Initial addition of MMAL video decoder support
- Issue #231 - revert to not randomizing artwork
- Issue #232 - fixed scraping of random system artworks
- Added Italian translation (author: P. Ghezzo)
* Sat Jul 16 2016 luke.nukem.jones@gmail.com
- Use the correct license SPDX
- Switch to pkgconfig for rpm build
- v2.1.0.
- Andrew Mickelson (14 commits)
  + * Version 2.1.0
  + * Issue #227 - randomly select artwork when matches are available from multiple paths
  + * Issue #228 - Fixed a couple of bugs when menus (exit, etc) are triggered by a joystick move
  + * [windows] Issue #199 - Console hiding is now configurable in attract.cfg. Default is off.
  + * [linux] Issue #228 - Fix "Z" and "R" joystick axes
  + * Added 6 second timeout when mapping a new input.
  + * Issue #225 - fix --build-romlist mame --full when no files found
  + * Issue #124 - Added support for hotkey combos
  + * [linux] Fixed emulator 'exit hotkey'
  + * Issue #167 - Filter by button count.
  + * Issue #216 - separate UI menu navigation (up.down,left,right,back,sel)
  + * [linux,rpi] Fixes when running emulator (in "Fullscreen Mode")
  + * [rpi] Allow changing the window mode setting on the rpi version
  + * Issue #215 - fix crash in fe.get_art() when image is missing
- Jeffrey Clark (3 commits)
  + * fix build when TR1 enabled
  + * support for libavcodec < 55.16
  + * replace deprecated AVPicture
